PyUrbanDict
===========

An unofficial Python wrapper to api of urbandictionary.com

Installation
~~~~~~~~~~~~

::

    git clone https://github.com/VatsalP/PyUrbanDict
    pip3 install -r requirements.txt
    python3 setup.py install

Run tests
~~~~~~~~~

To execute the tests, run:

::

    python3 -m pyurbandicttests.main_test
